Struct BoxMakeWriter
pub struct BoxMakeWriter { /* private fields */ }Expand description
A writer that erases the specific io::Write and MakeWriter types being used.
This is useful in cases where the concrete type of the writer cannot be known until runtime.
Examples
A function that returns a Subscriber that will write to either stdout or stderr:
fn dynamic_writer(use_stderr: bool) -> impl Subscriber {
let writer = if use_stderr {
BoxMakeWriter::new(std::io::stderr)
} else {
BoxMakeWriter::new(std::io::stdout)
};
tracing_subscriber::fmt().with_writer(writer).finish()
}Implementations
impl BoxMakeWriter
impl BoxMakeWriter
pub fn new<M>(make_writer: M) -> BoxMakeWriter
pub fn new<M>(make_writer: M) -> BoxMakeWriter
Constructs a BoxMakeWriter wrapping a type implementing MakeWriter.