Type Alias OptionalWriter
pub type OptionalWriter<T> = EitherWriter<T, Sink>;Expand description
A writer which may or may not be enabled.
This may be used by MakeWriter implementations that wish to
conditionally enable or disable the returned writer based on a span or
event’s [Metadata].
Aliased Type
pub enum OptionalWriter<T> {
A(T),
B(Sink),
}