__tracing_subscriber_field_MakeExt

Trait __tracing_subscriber_field_MakeExt 

pub trait __tracing_subscriber_field_MakeExt<T>:
    Sized
    + MakeVisitor<T>
    + Sealed<MakeExtMarker<T>> {
    // Provided methods
    fn debug_alt(self) -> Alt<Self> { ... }
    fn display_messages(self) -> Messages<Self> { ... }
    fn delimited<D>(self, delimiter: D) -> Delimited<D, Self>
       where D: AsRef<str> + Clone,
             Self::Visitor: VisitFmt { ... }
}
Extension trait providing MakeVisitor combinators.

Provided Methods

fn debug_alt(self) -> Alt<Self>

Wraps self so that any fmt::Debug fields are recorded using the alternate formatter ({:#?}).

fn display_messages(self) -> Messages<Self>

Wraps self so that any string fields named “message” are recorded using fmt::Display.

fn delimited<D>(self, delimiter: D) -> Delimited<D, Self>
where D: AsRef<str> + Clone, Self::Visitor: VisitFmt,

Wraps self so that when fields are formatted to a writer, they are separated by the provided delimiter.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors



impl<T, M> MakeExt<T> for M
where M: MakeVisitor<T> + Sealed<MakeExtMarker<T>>,