pub fn write_pause_state(state: Option<PauseState>) -> Result<()>Expand description
Write the pause state to disk, or remove the file when None.
pub fn write_pause_state(state: Option<PauseState>) -> Result<()>Write the pause state to disk, or remove the file when None.